==> JOB-3.1.2.tar.gz: JOB-3.1.2/ob/test/TestStubTimeout.java <==
// **********************************************************************
//
// Copyright (c) 1997
// Object-Oriented Concepts, Inc.
// Billerica, MA, USA
//
// Copyright (c) 1997
// Object-Oriented Concepts GmbH
// Ettlingen, Germany
//
// All Rights Reserved
//
// **********************************************************************

package test;

import org.omg.CORBA.*;

class TestStubTimeout extends TestBase
{
    TestStubTimeout(org.omg.CORBA.ORB orb, TestInterfaceTimeout tiOrig)
    {
        //
        // Create policy list containing new timeout policy
        //
        org.omg.CORBA.Policy[] pl = new org.omg.CORBA.Policy[1];
        org.omg.CORBA.Any any = orb.create_any();
        any.insert_long(2000);
        try
        {
	    //
	    // NOTE:  This can be changed to orb.create_policy when
	    //        2.3/Messaging is adopted.
	    //
            pl[0] = ((com.ooc.CORBA.ORB)orb).
		create_policy(com.ooc.OB.TIMEOUT_POLICY.value, any);
        }
        catch(org.omg.CORBA.PolicyError e)
        {
            TEST(false);
        }

        TestInterfaceTimeout ti = null;
        //
        // _set_policy_overrides returns new proxy, which this policy
        // applied.
        //
	try
	{
	    //
	    // NOTE:  This can be changed to tiOrig._set_policy... when
	    //        2.3/Messaging is adopted.
	    //
	    com.ooc.CORBA.Delegate d =
		(com.ooc.CORBA.Delegate)
		 ((org.omg.CORBA.portable.ObjectImpl)tiOrig)._get_delegate();
	    org.omg.CORBA.Object obj =
		d.set_policy_overrides(pl, org.omg.CORBA.SetOverrideType.
				       ADD_OVERRIDE);
	    //
	    // _narrow to correct type
	    //
	    ti = TestInterfaceTimeoutHelper.narrow(obj);
	}
	catch(org.omg.CORBA.PolicyManagerPackage.InvalidPolicies e)
	{
            TEST(false);
	}
        
	ti.sleepOneway(3);
	
	try
	{
	    ti.sleepTwoway(0);
	    TEST(false);
	}
	catch(org.omg.CORBA.NO_RESPONSE ex)
	{
	}
	
	try
	{
	    Thread.currentThread().sleep(2000);
	}
	catch(InterruptedException ex)
	{
	}

	try
	{
	    ti.sleepTwoway(0);
	}
	catch(org.omg.CORBA.NO_RESPONSE ex)
	{
	    TEST(false);
	}
    }
}

==> JOB-3.3.2.tar.gz: JOB-3.3.2/ob/test/TestStubTimeout.java <==
// **********************************************************************
//
// Copyright (c) 2000
// Object Oriented Concepts, Inc.
// Billerica, MA, USA
//
// All Rights Reserved
//
// **********************************************************************

package test;

import org.omg.CORBA.*;

class TestStubTimeout extends TestBase
{
    TestStubTimeout(TestIntf tiOrig, org.omg.CORBA.ORB orb)
    {
        //
        // Create policy list containing new timeout policy
        //
        org.omg.CORBA.Policy[] pl = new org.omg.CORBA.Policy[1];
        org.omg.CORBA.Any any = orb.create_any();
        any.insert_long(2000);
        try
        {
	    //
	    // NOTE:  This can be changed to orb.create_policy when
	    //        2.3/Messaging is adopted.
	    //
            pl[0] = ((com.ooc.CORBA.ORB)orb).
		create_policy(com.ooc.OB.TIMEOUT_POLICY.value, any);
        }
        catch(org.omg.CORBA.PolicyError e)
        {
            TEST(false);
        }

        TestIntf ti = null;
        //
        // _set_policy_override returns new proxy, with this policy
        // applied
        //
        org.omg.CORBA.Object obj =
            tiOrig._set_policy_override(
                pl, org.omg.CORBA.SetOverrideType.ADD_OVERRIDE);
        //
        // _narrow to correct type
        //
        ti = TestIntfHelper.narrow(obj);

	ti.sleepOneway(3);
	
	try
	{
	    ti.sleepTwoway(0);
	    TEST(false);
	}
	catch(org.omg.CORBA.NO_RESPONSE ex)
	{
	}
	
	try
	{
	    Thread.currentThread().sleep(2000);
	}
	catch(InterruptedException ex)
	{
	}

	try
	{
	    ti.sleepTwoway(0);
	}
	catch(org.omg.CORBA.NO_RESPONSE ex)
	{
	    TEST(false);
	}
    }
}
